import {
  Paper,
  Table,
  TableBody,
  TableCell,
  TableContainer,
  TableHead,
  TableRow,
} from '@mui/material'
import Page from 'components/page'
import { UserRoleLine } from 'components/roleLine'
import { useUserContext } from 'contexts'
import { FetchedRole, Role } from 'interfaces'
import { useEffect, useState } from 'react'
import { useTranslation } from 'react-i18next'
import { Redirect } from 'react-router-dom'
import { parseRole } from 'utils'

const GuestPage = () => {
  const { user } = useUserContext()

  const [t] = useTranslation('common')
  const [roles, setRoles] = useState<Role[]>([])
  useEffect(() => {
    setRoles(user.roles.map((role: FetchedRole) => parseRole(role)))
  }, [])
  return (
    <Page>
      <h4>{t('guestInfo.contactInfo')}</h4>
      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('guestInfo.contactInfo')}</TableCell>
              <TableCell />
            </TableRow>
          </TableHead>
          <TableBody>
            <TableRow>
              <TableCell align="left">{t('input.fullName')}</TableCell>
              <TableCell align="left">{`${user.first_name} ${user.last_name}`}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.email')}</TableCell>
              <TableCell align="left">{user.email}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('feideId')}</TableCell>
              <TableCell align="left">{user.feide_id}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.nationalIdNumber')}</TableCell>
              <TableCell align="left">{user.fnr}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.passportNumber')}</TableCell>
              <TableCell align="left">{user.passport}</TableCell>
            </TableRow>
            <TableRow>
              <TableCell align="left">{t('input.mobilePhone')}</TableCell>
              <TableCell align="left">{user.mobile_phone}</TableCell>
            </TableRow>
          </TableBody>
        </Table>
      </TableContainer>
      <h4>{t('guestInfo.roleInfoHead')}</h4>
      <TableContainer component={Paper}>
        <Table sx={{ minWidth: 650 }} aria-label="simple table">
          <TableHead sx={{ backgroundColor: 'primary.light' }}>
            <TableRow>
              <TableCell align="left">{t('common:role')}</TableCell>
              <TableCell align="left">{t('common:period')}</TableCell>
              <TableCell align="left">{t('common:ou')}</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {roles.map((role) => (
              <UserRoleLine key={role.id} role={role} />
            ))}
          </TableBody>
        </Table>
      </TableContainer>
    </Page>
  )
}

const AnonPage = () => {
  const [t] = useTranslation('common')
  return (
    <Page>
      <h4>{t('anonpage.top')}</h4>
      <p>{t('anonpage.body')}</p>
    </Page>
  )
}

function LandingPage() {
  const { user } = useUserContext()

  if (user.sponsor_id) {
    return <Redirect to="sponsor" />
  }
  if (user.person_id) {
    return <GuestPage />
  }
  return <AnonPage />
}

export default LandingPage
